@@ -6,19 +6,17 @@
 #include <gdk/gdk.h>    
 #include <gdk/gdkx.h>
 #include <gdk-pixbuf/gdk-pixdata.h>
-#include <libxfce4util/i18n.h>
-#include <libxfce4util/util.h>
+#include <libxfce4util/libxfce4util.h>
 #include <libxfcegui4/libxfcegui4.h>
 #include <libxfce4mcs/mcs-client.h>
-#include <libxfce4util/debug.h>
 
 #include "ls_iconboxconf.h"
-#include "inline-icon.h"
 
 #define CHANNEL "xfibx"
 #define LS_HEADER N_("Lil' Star - Iconbox")
 #define LS_TITLE N_("Lil' Star - Iconbox")
 
+#define RCDIR "xfce4" G_DIR_SEPARATOR_S "mcs_settings"
 
 /* CALLBACKS									*/
 static void cb_lsibc_alignment(GtkWidget *pWidget, gpointer pUserData);
@@ -35,7 +33,6 @@ LSIconBoxConf *ls_iconboxconf_create_configwin(LSIconBoxWin *plsibw)
   GtkWindow		*pWin;
   GtkWidget		*pDialogHeader;
   GtkFrame		*pFrame;
-  GtkHBox		*pHBox;
  
   /* This is required for UTF-8 at least - Please don't remove it  */
   xfce_textdomain(GETTEXT_PACKAGE, LOCALEDIR, "UTF-8");
@@ -50,7 +47,7 @@ LSIconBoxConf *ls_iconboxconf_create_configwin(LSIconBoxWin *plsibw)
   gtk_window_set_title(GTK_WINDOW(pWin), _(LS_TITLE));
   gtk_dialog_set_has_separator(GTK_DIALOG(pWin), FALSE);
   
-  pIcon = inline_icon_at_size(default_icon_data_48_48, 32, 32);
+  pIcon = xfce_themed_icon_load ("xfce4-iconbox", 48);
   pDialogHeader = create_header(pIcon, _(LS_HEADER));
 
   gtk_window_set_icon(GTK_WINDOW(pWin), pIcon);
@@ -98,23 +95,11 @@ LSIconBoxConf *ls_iconboxconf_create_configwin(LSIconBoxWin *plsibw)
   pFrame = GTK_FRAME(xfce_framebox_new (_("Appearance"), TRUE));
   gtk_box_pack_start(GTK_BOX(pp->widgets.main), GTK_WIDGET(pFrame), 
     FALSE, FALSE, 0);
-  pp->widgets.frame_2		= GTK_VBOX(gtk_vbox_new(FALSE, 0));
+  pp->widgets.frame_2		= GTK_VBOX(gtk_vbox_new(FALSE, 6));
   xfce_framebox_add (XFCE_FRAMEBOX (pFrame), GTK_WIDGET(pp->widgets.frame_2));
 
-  pp->widgets.frame_2_btn_group_1[0] =
-    GTK_RADIO_BUTTON(gtk_radio_button_new_with_label(NULL, _("Minimized only")));
-  pp->widgets.frame_2_btn_group_1[1] =
-    GTK_RADIO_BUTTON(gtk_radio_button_new_with_label(
-      gtk_radio_button_get_group(pp->widgets.frame_2_btn_group_1[0]),
-      _("All Apps")));
-
-  pHBox = GTK_HBOX(gtk_hbox_new(FALSE, 0));
-
-  gtk_box_pack_start(GTK_BOX(pHBox), 
-    GTK_WIDGET(pp->widgets.frame_2_btn_group_1[0]), FALSE, FALSE, 0);
-  gtk_box_pack_start(GTK_BOX(pHBox), 
-    GTK_WIDGET(pp->widgets.frame_2_btn_group_1[1]), FALSE, FALSE, 0);
-
+  pp->widgets.frame_2_btn_0 =
+    GTK_CHECK_BUTTON(gtk_check_button_new_with_label(_("Minimized only")));
   pp->widgets.frame_2_btn_1 = 
     GTK_CHECK_BUTTON(gtk_check_button_new_with_label(_("Show All Workspaces")));
   pp->widgets.frame_2_btn_2 = 
@@ -122,8 +107,8 @@ LSIconBoxConf *ls_iconboxconf_create_configwin(LSIconBoxWin *plsibw)
   pp->widgets.frame_2_btn_3 =
     GTK_CHECK_BUTTON(gtk_check_button_new_with_label(_("Hide if empty")));
 
-  gtk_box_pack_start(GTK_BOX(pp->widgets.frame_2), GTK_WIDGET(pHBox),
-    FALSE, FALSE, 0);
+  gtk_box_pack_start(GTK_BOX(pp->widgets.frame_2), 
+    GTK_WIDGET(pp->widgets.frame_2_btn_0), FALSE, FALSE, 0);
   gtk_box_pack_start(GTK_BOX(pp->widgets.frame_2), 
     GTK_WIDGET(pp->widgets.frame_2_btn_1), FALSE, FALSE, 0);
   gtk_box_pack_start(GTK_BOX(pp->widgets.frame_2), 
@@ -163,11 +148,8 @@ void ls_iconboxconf_connect_signals(LSIconBoxConf *plsibw)
     "toggled", G_CALLBACK(cb_lsibc_alignment), plsibw);
     
   /* START SECOND FRAME								*/
-  g_signal_connect(G_OBJECT(pp->widgets.frame_2_btn_group_1[0]), 
+  g_signal_connect(G_OBJECT(pp->widgets.frame_2_btn_0), 
     "toggled", G_CALLBACK(cb_lsibc_show), plsibw);
-  g_signal_connect(G_OBJECT(pp->widgets.frame_2_btn_group_1[1]), 
-    "toggled", G_CALLBACK(cb_lsibc_show), plsibw);
-
   g_signal_connect(G_OBJECT(pp->widgets.frame_2_btn_1), 
     "toggled", G_CALLBACK(cb_lsibc_show), plsibw);
   g_signal_connect(G_OBJECT(pp->widgets.frame_2_btn_2), 
@@ -250,12 +232,12 @@ void ls_iconboxconf_re_evaluate_settings(LSIconBoxConf *plsibc)
     if(pSetting->data.v_int && !pSetting2->data.v_int)
     {
       gtk_toggle_button_set_active(
-        GTK_TOGGLE_BUTTON(pp->widgets.frame_2_btn_group_1[0]), TRUE);
+        GTK_TOGGLE_BUTTON(pp->widgets.frame_2_btn_0), TRUE);
     }
     else if(pSetting->data.v_int && pSetting2->data.v_int)
     {
       gtk_toggle_button_set_active(
-        GTK_TOGGLE_BUTTON(pp->widgets.frame_2_btn_group_1[1]), TRUE);
+        GTK_TOGGLE_BUTTON(pp->widgets.frame_2_btn_0), FALSE);
     }
 
     if(pSetting3->data.v_int || pSetting4->data.v_int)
@@ -318,14 +300,11 @@ void ls_iconboxconf_set_mcsmanager(
 
 gboolean ls_iconboxconf_write(LSIconBoxConf *plsibwcw, McsManager *pmcsm)
 {
-  const gchar 	*szHome;
   gchar		*szRcFile;
   gboolean	bErr;
 
-  szHome 	= g_get_home_dir(); 
-  szRcFile	= g_strconcat(szHome, G_DIR_SEPARATOR_S, ".xfce4", 
-      		    G_DIR_SEPARATOR_S, "settings", G_DIR_SEPARATOR_S, 
-		    "ls-iconbox.xml", NULL);
+  szRcFile = xfce_resource_save_location(XFCE_RESOURCE_CONFIG,
+                RCDIR G_DIR_SEPARATOR_S "ls-iconbox.xml", TRUE);
 
   if(plsibwcw == NULL) 
   {
@@ -353,13 +332,16 @@ gboolean ls_iconboxconf_write(LSIconBoxConf *plsibwcw, McsManager *pmcsm)
 
 gboolean ls_iconboxconf_read(LSIconBoxConf *plsibwcw, McsManager *pmcsm)
 {
-  const gchar 	*szHome;
   gchar		*szRcFile;
 
-  szHome 	= g_get_home_dir(); 
-  szRcFile	= g_strconcat(szHome, G_DIR_SEPARATOR_S, ".xfce4", 
-      		    G_DIR_SEPARATOR_S, "settings", G_DIR_SEPARATOR_S,
-		    "ls-iconbox.xml", NULL);
+  szRcFile = xfce_resource_lookup (XFCE_RESOURCE_CONFIG, 
+                                   RCDIR G_DIR_SEPARATOR_S "ls-iconbox.xml");
+  
+  if (!szRcFile)
+  {
+      szRcFile	= xfce_get_userfile("settings", G_DIR_SEPARATOR_S, 
+				    "ls-iconbox.xml", NULL);
+  }
 
   if(plsibwcw == NULL) 
   {
@@ -376,11 +358,17 @@ gboolean ls_iconboxconf_read(LSIconBoxConf *plsibwcw, McsManager *pmcsm)
     return FALSE;
   };
   
-  mcs_manager_add_channel_from_file(pmcsm, CHANNEL, szRcFile);
+  if (g_file_test (szRcFile, G_FILE_TEST_EXISTS))
+      mcs_manager_add_channel_from_file(pmcsm, CHANNEL, szRcFile);
+  else
+      mcs_manager_add_channel (pmcsm, CHANNEL);
+  
   mcs_manager_set_int(pmcsm, "Config/Read", CHANNEL, 1);
 
   g_free(szRcFile);
 
+  ls_iconboxconf_write(plsibwcw, pmcsm);
+  
   return TRUE;
 };
 
@@ -484,8 +472,8 @@ static void cb_lsibc_show(GtkWidget *pWidget, gpointer pUserData)
   pManager		= plsibwcw->priv->pmcsManager;
   g_return_if_fail(pManager!=NULL);
 
-  bAllApps	= gtk_toggle_button_get_active(
-      		    GTK_TOGGLE_BUTTON(pp->widgets.frame_2_btn_group_1[1]));
+  bAllApps	= !gtk_toggle_button_get_active(
+      		    GTK_TOGGLE_BUTTON(pp->widgets.frame_2_btn_0));
   bAllWS	= gtk_toggle_button_get_active(
       		    GTK_TOGGLE_BUTTON(pp->widgets.frame_2_btn_1));
 
